# Welcome to swarms Docs Home

[![Join our Discord](https://img.shields.io/badge/Discord-Join%20our%20server-5865F2?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/jM3Z6M9uMq) [![Subscribe on YouTube](https://img.shields.io/badge/YouTube-Subscribe-red?style=for-the-badge&logo=youtube&logoColor=white)](https://www.youtube.com/@kyegomez3242) [![Connect on LinkedIn](https://img.shields.io/badge/LinkedIn-Connect-blue?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/kye-g-38759a207/) [![Follow on X.com](https://img.shields.io/badge/X.com-Follow-1DA1F2?style=for-the-badge&logo=x&logoColor=white)](https://x.com/kyegomezb)

**Get Started Building Production-Grade Multi-Agent Applications**

## Onboarding

| Section                        | Links                                                                                                   |
| ------------------------------ | ------------------------------------------------------------------------------------------------------- |
| Installation                   | [Installation](https://docs.swarms.world/en/latest/swarms/install/install/)                             |
| Quickstart                     | [Get Started](https://docs.swarms.world/en/latest/swarms/install/quickstart/)                           |
| Environment Setup              | [Environment Configuration](https://docs.swarms.world/en/latest/swarms/install/workspace_manager/)      |
| Environment Variables          | [Environment Variables](https://docs.swarms.world/en/latest/swarms/install/env/)                        |
| swarms CLI                     | [CLI Documentation](https://docs.swarms.world/en/latest/swarms/cli/main/)                               |
| Agent Internal Mechanisms      | [Agent Architecture](https://docs.swarms.world/en/latest/swarms/framework/agents_explained/)            |
| Agent API                      | [Agent API](https://docs.swarms.world/en/latest/swarms/structs/agent/)                                  |
| Managing Prompts in Production | [Prompts Management](https://docs.swarms.world/en/latest/swarms/prompts/main/)                          |
| Integrating External Agents    | [External Agents Integration](https://docs.swarms.world/en/latest/swarms/agents/external_party_agents/) |
| Creating Agents from YAML      | [YAML Agent Creation](https://docs.swarms.world/en/latest/swarms/agents/create_agents_yaml/)            |
| Why You Need swarms            | [Why MultiAgent Collaboration](https://docs.swarms.world/en/latest/swarms/concept/why/)                 |
| Swarm Architectures Analysis   | [Swarm Architectures](https://docs.swarms.world/en/latest/swarms/concept/swarm_architectures/)          |
| Choosing the Right Swarm       | [How to Choose swarms](https://docs.swarms.world/en/latest/swarms/concept/how_to_choose_swarms/)        |
| Full API Reference             | [API Reference](https://docs.swarms.world/en/latest/swarms/framework/reference/)                        |
| AgentRearrange Docs            | [AgentRearrange](https://docs.swarms.world/en/latest/swarms/structs/agent_rearrange/)                   |

## Ecosystem

Here you'll find references about the swarms framework, marketplace, community, and more to enable you to build your multi-agent applications.

| Section                      | Links                                                                          |
| ---------------------------- | ------------------------------------------------------------------------------ |
| swarms Python Framework Docs | [Framework Docs](https://docs.swarms.world/en/latest/swarms/install/install/)  |
| swarms Cloud API             | [Cloud API](https://docs.swarms.world/en/latest/swarms_cloud/launch/)          |
| swarms Marketplace API       | [Marketplace API](https://docs.swarms.world/en/latest/swarms_platform/)        |
| swarms Memory Systems        | [Memory Systems](https://docs.swarms.world/en/latest/swarms_memory/)           |
| Available Models             | [Models Overview](https://docs.swarms.world/en/latest/swarms/models/)          |
| swarms Tools                 | [Tools Overview](https://docs.swarms.world/en/latest/swarms_tools/overview/)   |
| Example Applications         | [Examples](https://docs.swarms.world/en/latest/swarms/examples/unique_swarms/) |
| swarms Corp Github           | [swarms Corp GitHub](https://github.com/The-Swarm-Corporation)                 |

## Community

| Section           | Links                                 |
| ----------------- | ------------------------------------- |
| Community         | [Discord](https://discord.gg/swarms)  |
| Blog              | [Blog](https://medium.com/@kyeg)      |
| Event Calendar    | [LUMA](https://lu.ma/swarms_calendar) |
| Twitter           | [Twitter](https://x.com/swarms_corp)  |
| Agent Marketplace | [Website](https://swarms.world)       |
| Docs              | [Website](https://docs.swarms.world)  |
| swarms Website    | [Website](https://swarms.ai)          |

## Get Support

Want to get in touch with the swarms team? Open an issue on [GitHub](https://github.com/kyegomez/swarms/issues/new) or reach out to us via [email](mailto:kye@swarms.world). We're here to help!
